-- widget title=Assessment overview, row=0, col=0, size_x=8, size_y=3

# Assessment Overview

[Quick link to dashboard documentation](https://github.com/databrickslabs/ucx/blob/main/docs/assessment.md)
